@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (C) 2008 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
@@ -18,11 +19,12 @@
 #include "k3bmedium.h"
 #include "k3bcdtext.h"
 
-#include <KLocale>
+#include <KI18n/KLocalizedString>
 
-#include <libkcddb/cdinfo.h>
+#include <KCddb/Cdinfo>
 
 #include <QtCore/QMimeData>
+#include <QtGui/QFont>
 
 Q_DECLARE_METATYPE( K3b::Medium )
 Q_DECLARE_METATYPE( K3b::Msf )
@@ -109,19 +111,24 @@ K3b::AudioTrackModel::~AudioTrackModel()
 
 void K3b::AudioTrackModel::setMedium( const K3b::Medium& medium )
 {
+    beginResetModel();
     d->medium = medium;
     d->itemCheckedList.resize( d->medium.toc().count() );
     for ( int i = 0; i < d->medium.toc().count(); ++i ) {
-        d->itemCheckedList[i] = true;
+        if( d->medium.toc()[i].type() == K3b::Device::Track::TYPE_AUDIO )
+            d->itemCheckedList[i] = true;
+        else
+            d->itemCheckedList[i] = false;
     }
-    reset();
+    endResetModel();
 }
 
 
 void K3b::AudioTrackModel::setCddbInfo( const KCDDB::CDInfo& data )
 {
+    beginResetModel();
     d->cddbCache = data;
-    reset();
+    endResetModel();
 }
 
 
@@ -167,7 +174,7 @@ QVariant K3b::AudioTrackModel::headerData( int section, Qt::Orientation orientat
 
 QVariant K3b::AudioTrackModel::data( const QModelIndex& index, int role ) const
 {
-//    kDebug() << index << role;
+//    qDebug() << index << role;
 
     // FIXME: add a cache for all the values that can be changed (maybe a local KCDDB::CDInfo)
     // which will then be the first choice for all values
@@ -201,7 +208,12 @@ QVariant K3b::AudioTrackModel::data( const QModelIndex& index, int role ) const
         case ArtistColumn:
             return d->getField( KCDDB::Artist, trackIndex );
         case TitleColumn:
-            return d->getField( KCDDB::Title, trackIndex );
+        {
+            if( d->medium.toc()[trackIndex].type() == Device::Track::TYPE_DATA )
+                return i18n( "Data Track" );
+            else
+                return d->getField( KCDDB::Title, trackIndex );
+        }
         case LengthColumn:
             return d->medium.toc()[trackIndex].length().toString();
         }
@@ -218,6 +230,14 @@ QVariant K3b::AudioTrackModel::data( const QModelIndex& index, int role ) const
             return Qt::AlignHCenter;
         }
         break;
+        
+    case Qt::FontRole:
+        if( d->medium.toc()[trackIndex].type() == Device::Track::TYPE_DATA )
+        {
+            QFont font;
+            font.setItalic( true );
+            return font;
+        }
     }
 
     return QVariant();
@@ -226,17 +246,14 @@ QVariant K3b::AudioTrackModel::data( const QModelIndex& index, int role ) const
 
 Qt::ItemFlags K3b::AudioTrackModel::flags( const QModelIndex& index ) const
 {
-    Qt::ItemFlags f = Qt::ItemIsSelectable;
+    Qt::ItemFlags f = 0;
 
-    if ( d->medium.toc().count() > index.row() &&
+    if ( index.isValid() && index.row() >= 0 && index.row() < d->medium.toc().count() &&
          d->medium.toc()[index.row()].type() == K3b::Device::Track::TYPE_AUDIO ) {
 
-        f |= Qt::ItemIsDragEnabled|Qt::ItemIsEnabled;
+        f |= Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
 
         switch( index.column() ) {
-        case TrackNumberColumn:
-            f |= Qt::ItemIsUserCheckable;
-            break;
         case ArtistColumn:
         case TitleColumn:
             f |= Qt::ItemIsEditable;
@@ -283,7 +300,7 @@ void K3b::AudioTrackModel::setTrackChecked( int track, bool checked )
 {
     if ( track >= 0 && track < d->itemCheckedList.count() ) {
         d->itemCheckedList[track] = checked;
-        emit dataChanged( index( track, 0 ), index( track, 0 ) );
+        emit dataChanged( index( track, TrackNumberColumn ), index( track, TrackNumberColumn ) );
     }
 }
 
@@ -291,8 +308,7 @@ void K3b::AudioTrackModel::setTrackChecked( int track, bool checked )
 bool K3b::AudioTrackModel::trackChecked( int trackIndex ) const
 {
     if ( trackIndex >= 0 &&
-         trackIndex < d->medium.toc().count() &&
-         d->medium.toc()[trackIndex].type() == K3b::Device::Track::TYPE_AUDIO ) {
+         trackIndex < d->medium.toc().count() ) {
         return d->itemCheckedList[trackIndex];
     }
     else {
@@ -368,7 +384,7 @@ QMimeData* K3b::AudioTrackModel::mimeData( const QModelIndexList& indexes ) cons
     // d'n'd is not a problem
     QList<int> trackNumbers;
     foreach( const QModelIndex& index, indexes ) {
-        if ( index.column() == 0 )
+        if ( index.column() == TrackNumberColumn )
             trackNumbers << index.data( TrackNumberColumn ).toInt();
     }
     AudioCdTrackDrag drag( d->medium.toc(), trackNumbers, d->cddbCache, d->medium.device() );
@@ -383,7 +399,7 @@ void K3b::AudioTrackModel::checkAll()
     for ( int i = 0; i < d->medium.toc().count(); ++i ) {
         d->itemCheckedList[i] = true;
     }
-    emit dataChanged( index( 0, 0 ), index( d->itemCheckedList.count(), 0 ) );
+    emit dataChanged( index( 0, TrackNumberColumn ), index( d->itemCheckedList.count(), TrackNumberColumn ) );
 }
 
 
@@ -392,7 +408,7 @@ void K3b::AudioTrackModel::uncheckAll()
     for ( int i = 0; i < d->medium.toc().count(); ++i ) {
         d->itemCheckedList[i] = false;
     }
-    emit dataChanged( index( 0, 0 ), index( d->itemCheckedList.count(), 0 ) );
+    emit dataChanged( index( 0, TrackNumberColumn ), index( d->itemCheckedList.count(), TrackNumberColumn ) );
 }
 
-#include "k3baudiotrackmodel.moc"
+
